@@ -26,15 +26,13 @@ from zaqar.common import configs
 from zaqar.common import consts
 from zaqar.common import decorators
 from zaqar.common import errors
-from zaqar import profile
 from zaqar.storage import pipeline
 from zaqar.storage import pooling
 from zaqar.storage import utils as storage_utils
 from zaqar.transport import base
+from zaqar.transport.middleware import profile
 from zaqar.transport import validation
 
-from zaqar.i18n import _LE
-
 LOG = log.getLogger(__name__)
 
 
@@ -53,7 +51,7 @@ class Bootstrap(object):
         profiler_opts.set_defaults(self.conf)
 
         # TODO(wangxiyuan): Now the OSprofiler feature in Zaqar only support
-        # wsgi. Websockt part will be added in the future.
+        # wsgi. Websocket part will be added in the future.
         profile.setup(self.conf, 'Zaqar-server', socket.gethostname())
 
         self.driver_conf = self.conf[configs._DRIVER_GROUP]
@@ -122,8 +120,8 @@ class Bootstrap(object):
             return mgr.driver
         except RuntimeError as exc:
             LOG.exception(exc)
-            LOG.error(_LE(u'Failed to load transport driver zaqar.transport.'
-                          u'%(driver)s with args %(args)s'),
+            LOG.error(u'Failed to load transport driver zaqar.transport.'
+                      u'%(driver)s with args %(args)s',
                       {'driver': transport_name, 'args': args})
             raise errors.InvalidDriver(exc)
 
