@@ -22,7 +22,6 @@ from stevedore import driver
 
 from zaqar.common import errors
 from zaqar.common import utils
-from zaqar.i18n import _LE
 from zaqar.storage import configuration
 
 LOG = log.getLogger(__name__)
@@ -64,13 +63,11 @@ def dynamic_conf(uri, options, conf=None):
         driver_opts = utils.dict_to_conf({'message_store': storage_type})
         conf.register_opts(driver_opts, group=u'drivers')
 
-    conf.set_override('message_store', storage_type, 'drivers',
-                      enforce_type=True)
+    conf.set_override('message_store', storage_type, 'drivers')
 
     for opt in options:
         if opt in conf[storage_group]:
-            conf.set_override(opt, options[opt], group=storage_group,
-                              enforce_type=True)
+            conf.set_override(opt, options[opt], group=storage_group)
     return conf
 
 
@@ -120,7 +117,6 @@ def load_storage_driver(conf, cache, storage_type=None,
         instance to pass to the storage driver. Needed to access
         the queue controller, mainly.
     """
-
     if control_mode:
         mode = 'control'
         storage_type = storage_type or conf['drivers'].management_store
@@ -150,7 +146,7 @@ def load_storage_driver(conf, cache, storage_type=None,
             return mgr.driver
 
     except Exception as exc:
-        LOG.error(_LE('Failed to load "{}" driver for "{}"').format(
+        LOG.error('Failed to load "{}" driver for "{}"'.format(
             driver_type, storage_type))
         LOG.exception(exc)
         raise errors.InvalidDriver(exc)
@@ -197,20 +193,20 @@ def can_connect(uri, conf=None):
     :returns: True if can connect else False
     :rtype: bool
     """
+    # NOTE(cabrera): create a mock configuration containing only
+    # the URI field. This should be sufficient to initialize a
+    # storage driver.
     conf = dynamic_conf(uri, {}, conf=conf)
     storage_type = six.moves.urllib_parse.urlparse(uri).scheme
 
     try:
-        # NOTE(cabrera): create a mock configuration containing only
-        # the URI field. This should be sufficient to initialize a
-        # storage driver.
+        ctrl = load_storage_driver(conf, None,
+                                   storage_type=conf.drivers.management_store,
+                                   control_mode=True)
         driver = load_storage_driver(conf, None,
                                      storage_type=storage_type,
-                                     control_driver=load_storage_driver
-                                     (conf, None,
-                                      storage_type=storage_type,
-                                      control_mode=True))
+                                     control_driver=ctrl)
         return driver.is_alive()
     except Exception as exc:
-        LOG.debug('Can\'t connect to: %s \n%s' % (uri, exc))
+        LOG.debug('Can\'t connect to: %s \n%s', (uri, exc))
         return False
